==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/addressbook/language/cs.php <==
<?php


$l['name'] = 'Adresář';
$l['description'] = 'Adresář slouží k uložení kontaktů a k jejich úpravě.';
$l['allAddressbooks'] = 'Všechny Adresáře';
$lang['common']['addressbookAlreadyExists'] = 'Snažíte se vytvořit adresář, který již existuje';
$l['notIncluded'] = 'Neimportovat';
$l['comment'] = 'Komentář';
$l['bankNo'] = 'Číslo účtu'; ;
$l['vatNo'] = 'Daň z přidané hodnoty';
$l['contactsGroup'] = 'Skupina';
$lang['link_type'][2]=$l['contact'] = 'Kontakt';
$lang['link_type'][3]=$l['company'] = 'Společnost';
$l['customers'] = 'Zákazníci';
$l['suppliers'] = 'Dodavatelé';
$l['prospects'] = 'Perspektivy';
$l['contacts'] = 'Kontakty';
$l['companies'] = 'Společnosti';
$l['newContactAdded']='Nový kontakt přidán';
$l['newContactFromSite']='Nový kontakt byl přidán přes webový formulář.';
$l['clickHereToView']='Klikni zde pro zobrazení kontaktu';
$l['contactFromAddressbook']='Kontakt od %s';
$l['companyFromAddressbook']='Společnost od %s';
$l['defaultSalutation']='Milý/Milá [Pane/Paní] {middle_name} {last_name}';
$l['multipleSelected']='Vybráno více adresářů';
$l['incomplete_delete_contacts']='Nemáte oprávnění pro smazání všech vybraných kontaktů';
$l['incomplete_delete_companies']='Nemáte oprávnění pro smazání všech vybraných společností';
$l['emailAlreadyExists']='E-mailová adresa je již přidána k tomuto kontaktu';
$l['emailDoesntExists']='E-mailová adresa nebyla nalezena';
$l['imageNotSupported']='Nahraný typ obrázku není podporován. Podporovány jsou pouze obrázky typu: gif, png a jpg.';

$l["newSearch"]='Nové hledání';
$l["executeQuery"]='Spustit vyhledávací dotaz';
$l["savedQueries"]='Uložené vyhledávací dotazy';
$l["selectField"]= 'Vyberte pole';
$l["selectMailingGroup"]='Vyberte skupinu pro odesílání';
$l["cmdFormLabelAddressBooks"]= 'Vyberte adresář';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'Všechna pole';
$l["btnAddContact"]= 'Přidat kontakt'	;
$l["btnAddCompany"]= 'Přidat společnost';
$l["btnManage"]= 'Upravit';
$l["btnDownload"]= 'Nahrát soubor';
$l["cmdFormSearchFirst"]= 'Hledat v= ';
$l["cmdFormSearchSecond"]= ' on= ';
$l["cmdFormSearchThird"]= ' for= ';
$l["cmdFormSearchFourth"]= '(Používejte \'%\' jako zástupný znak) ';
$l["cmdFormLabelTitleInitials"]= 'Titul/Iniciály';
$l["cmdFormLabelSalutation"]= 'Oslovení';
$l["cmdFormLabelComment"]= 'Komentář';
$l["cmdFormCompanyEmptyText"]= 'Prosím, vyberte společnost';
$l["cmdFieldsetSelectAddressbook"]= 'Adresář';
$l["cmdFieldsetPersonalDetails"]= 'Profil kontaktu';
$l["cmdFieldsetAddress"]= 'Adresa';
$l["cmdFieldsetContact"]= 'Kontakt';
$l["cmdFieldsetWork"]= 'Práce';
$l["cmdPanelContact"]= 'Detail kontaktu';
$l["cmdPanelComments"]= 'Komentář';
$l["cmdContactDialog"]= 'Upravit kontakt';
$l["contact"]= 'Kontakt';
$l["cmdSalutation"]= 'Milý(á)';
$l["cmdMadam"]= 'paní';
$l["cmdSir"]= 'pane';
$l["btnDownloadTextDocument"]= 'Stáhnout Textový dokument';
$l["cmdContactDetailsFor"]= 'Profil';
$l["cmdLInkFieldset"]= 'Odkaz';
$l["company"]= 'Společnost';
$l["cmdCompanyDetailsFor"]= 'Profil';
$l["cmdPanelCompany"]= 'Profil společnosti';
$l["cmdFormLabelBankNo"]= 'Číslo účtu';
$l["cmdFormLabelVatNo"]= 'DPH';
$l["cmdFieldsetCompanyDetails"]= 'Profil společnosti';
$l["cmdFieldsetVisitAddress"]= 'Přechodná adresa';
$l["cmdFieldsetPostAddress"]= 'Adresa';
$l["cmdCompanyDialog"]= 'Upravit společnost';
$l["cmdPanelEmployees"]= 'Zaměstnanci';
$l["cmdPanelEmployee"]= 'Zaměstnanec';
$l["cmdAllEmployeesForThisCompany"]= 'Všichni zaměstnanci této společnosti';
$l["cmdFieldsetVisitAddress"]= 'Přechodná adresa';
$l["cmdFieldsetPostAddress"]= 'Adresa';
$l["cmdManageDialog"]= 'Upravit';
$l["cmdAddAddressBook"]= 'Přidat adresář';
$l["cmdDeleteAddressbook"]= 'Smazat adresář';
$l["cmdOwner"]= 'Vlastník';
$l["cmdPanelAddressbook"]= 'Adresáře';
$l["cmdPanelProperties"]= 'Nastavení';
$l["cmdContactDialog"]= 'Upravit kontakt';
$l["cmdFormLabelFileType"]= 'Typ souboru';
$l["cmdFormLabelFile"]= 'Soubor';	;
$l["cmdFormLabelValueSeperated"]= 'Hodnoty odděleny pomocí';
$l["cmdFormLabelValueIncluded"]= 'Hodnoty uzavřeny pomocí';
$l["cmdFormLabelLinesEnded"]= 'Konec řádky podle';
$l["cmdUpload"]= 'Nahrát';
$l["cmdImport"]= 'Importovat';
$l["cmdExport"]= 'Exportovat';
$l["cmdType"]= 'Typ';
$l["contacts"]= 'Kontakty';
$l["companies"]= 'Společnosti';
$l["users"]= 'Uživatelé';
$l["strSelectContact"]= 'Vybrat kontakt';
$l["strSelectCompany"]= 'Vybrat společnost';
$l["noAddressbooks"]= 'Neexistují žádné adresáře';
$l["moveAll"]= 'Společnosti a všichni zaměstnanci budou přesunuty do nového adresáře. Jste si jisti, že to chcete udělat?';
$l["addressbook"]= 'Adresář';
$l["addressbooks"]= 'Adresáře';
$l["sendMailing"]='Rozeslat nové zprávy';
$l["importSuccess"]='Data byly v pořádku importována';
$l["searchOnSender"]='Najít';
$l["confirmCreate"]='Kontakt neexistuje. Chcete založit nový?';
$l["matchFields"]='Shodné údaje';
$l["advancedSearch"]='Rozšířené vyhledávání';
$l["defaultAddressFormat"]='Výchozí formát adresy';
$l["defaultSalutation"]='Výchozí pozdrav';
$l["explanationVariables"]='Nápověda k zakládním proměnným pozdravů';
$l["explanationSex"]='Mužská a ženská podoba pozdravu';
$l["searchQueryName"]='Vyhledat název dotazu';
$l["enterSearchQueryName"]='Vložte název vyhledávacího dotazu:';
$l["photo"]= 'Fotografie';
$l["deleteImage"]='Smazat obrázek';
$l["addAllSearchResults"]='Přidat všechny výsledky vyhledávání';
$l["confirmAddAllSearchResults"]='Jste si jisti, že chcete přidat všechny výsledky hledání do seznamu adres?';
$l["moveEmployees"]='Přesunout zaměstnance';
$l["emailAdded"]='E-mailová adresa byla v pořádku přidána ke kontaktu';
$l["exportWithCompanies"]='Včetně společností';
$l["id"]='ID';
$l["exportPermission"]='Oprávnění exportu';
$l["crn"]='Společnost Reg. číslo';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Neznámá e-mailová adresa';
$l["strUnknownEmail"]= 'Tato e-mailová adresa je neznámá. Opravdu ji chcete přidat k novému kontaktu, přiřadit ke stávajícímu nebo zrušit?';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/addressbook/language/cs.php <==
<?php


$l['name'] = 'Adresář';
$l['description'] = 'Adresář slouží k uložení kontaktů a k jejich úpravě.';
$l['allAddressbooks'] = 'Všechny Adresáře';
$lang['common']['addressbookAlreadyExists'] = 'Snažíte se vytvořit adresář, který již existuje';
$l['notIncluded'] = 'Neimportovat';
$l['comment'] = 'Komentář';
$l['bankNo'] = 'Číslo účtu'; ;
$l['vatNo'] = 'Daň z přidané hodnoty';
$l['contactsGroup'] = 'Skupina';
$lang['link_type'][2]=$lang['link_type'][3]=$l['customers'] = 'Zákazníci';
$l['suppliers'] = 'Dodavatelé';
$l['prospects'] = 'Perspektivy';
$l['newContactAdded']='Nový kontakt přidán';
$l['newContactFromSite']='Nový kontakt byl přidán přes webový formulář.';
$l['clickHereToView']='Klikni zde pro zobrazení kontaktu';
$l['contactFromAddressbook']='Kontakt od %s';
$l['companyFromAddressbook']='Společnost od %s';
$l['multipleSelected']='Vybráno více adresářů';
$l['incomplete_delete_contacts']='Nemáte oprávnění pro smazání všech vybraných kontaktů';
$l['incomplete_delete_companies']='Nemáte oprávnění pro smazání všech vybraných společností';
$l['emailAlreadyExists']='E-mailová adresa je již přidána k tomuto kontaktu';
$l['emailDoesntExists']='E-mailová adresa nebyla nalezena';
$l['imageNotSupported']='Nahraný typ obrázku není podporován. Podporovány jsou pouze obrázky typu: gif, png a jpg.';

$l["newSearch"]='Nové hledání';
$l["executeQuery"]='Spustit vyhledávací dotaz';
$l["savedQueries"]='Uložené vyhledávací dotazy';
$l["selectField"]= 'Vyberte pole';
$l["selectMailingGroup"]='Vyberte skupinu pro odesílání';
$l["cmdFormLabelAddressBooks"]= 'Vyberte adresář';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z';
$l["cmdAllFields"]= 'Všechna pole';
$l["btnAddContact"]= 'Přidat kontakt'	;
$l["btnAddCompany"]= 'Přidat společnost';
$l["btnManage"]= 'Upravit';
$l["btnDownload"]= 'Nahrát soubor';
$l["cmdFormSearchFirst"]= 'Hledat v= ';
$l["cmdFormSearchSecond"]= ' on= ';
$l["cmdFormSearchThird"]= ' for= ';
$l["cmdFormSearchFourth"]= '(Používejte \'%\' jako zástupný znak) ';
$l["cmdFormLabelTitleInitials"]= 'Titul/Iniciály';
$l["cmdFormLabelSalutation"]= 'Oslovení';
$l["cmdFormLabelComment"]= 'Komentář';
$l["cmdFormCompanyEmptyText"]= 'Prosím, vyberte společnost';
$l["cmdFieldsetSelectAddressbook"]= 'Adresář';
$l["cmdFieldsetPersonalDetails"]= 'Profil kontaktu';
$l["cmdFieldsetAddress"]= 'Adresa';
$l["cmdFieldsetContact"]= 'Kontakt';
$l["cmdFieldsetWork"]= 'Práce';
$l["cmdPanelContact"]= 'Detail kontaktu';
$l["cmdPanelComments"]= 'Komentář';
$l["contact"]= 'Kontakt';
$l["cmdSalutation"]= 'Milý(á)';
$l["cmdMadam"]= 'paní';
$l["cmdSir"]= 'pane';
$l["btnDownloadTextDocument"]= 'Stáhnout Textový dokument';
$l["cmdContactDetailsFor"]= 'Profil';
$l["cmdLInkFieldset"]= 'Odkaz';
$l["company"]= 'Společnost';
$l["cmdCompanyDetailsFor"]= 'Profil';
$l["cmdPanelCompany"]= 'Profil společnosti';
$l["cmdFormLabelBankNo"]= 'Číslo účtu';
$l["cmdFormLabelVatNo"]= 'DPH';
$l["cmdFieldsetCompanyDetails"]= 'Profil společnosti';
$l["cmdCompanyDialog"]= 'Upravit společnost';
$l["cmdPanelEmployees"]= 'Zaměstnanci';
$l["cmdPanelEmployee"]= 'Zaměstnanec';
$l["cmdAllEmployeesForThisCompany"]= 'Všichni zaměstnanci této společnosti';
$l["cmdFieldsetVisitAddress"]= 'Přechodná adresa';
$l["cmdFieldsetPostAddress"]= 'Adresa';
$l["cmdManageDialog"]= 'Upravit';
$l["cmdAddAddressBook"]= 'Přidat adresář';
$l["cmdDeleteAddressbook"]= 'Smazat adresář';
$l["cmdOwner"]= 'Vlastník';
$l["cmdPanelAddressbook"]= 'Adresáře';
$l["cmdPanelProperties"]= 'Nastavení';
$l["cmdContactDialog"]= 'Upravit kontakt';
$l["cmdFormLabelFileType"]= 'Typ souboru';
$l["cmdFormLabelFile"]= 'Soubor';	;
$l["cmdFormLabelValueSeperated"]= 'Hodnoty odděleny pomocí';
$l["cmdFormLabelValueIncluded"]= 'Hodnoty uzavřeny pomocí';
$l["cmdFormLabelLinesEnded"]= 'Konec řádky podle';
$l["cmdUpload"]= 'Nahrát';
$l["cmdImport"]= 'Importovat';
$l["cmdExport"]= 'Exportovat';
$l["cmdType"]= 'Typ';
$l["contacts"]= 'Kontakty';
$l["companies"]= 'Společnosti';
$l["users"]= 'Uživatelé';
$l["strSelectContact"]= 'Vybrat kontakt';
$l["strSelectCompany"]= 'Vybrat společnost';
$l["noAddressbooks"]= 'Neexistují žádné adresáře';
$l["moveAll"]= 'Společnosti a všichni zaměstnanci budou přesunuty do nového adresáře. Jste si jisti, že to chcete udělat?';
$l["addressbook"]= 'Adresář';
$l["addressbooks"]= 'Adresáře';
$l["sendMailing"]='Rozeslat nové zprávy';
$l["importSuccess"]='Data byly v pořádku importována';
$l["searchOnSender"]='Najít';
$l["confirmCreate"]='Kontakt neexistuje. Chcete založit nový?';
$l["matchFields"]='Shodné údaje';
$l["advancedSearch"]='Rozšířené vyhledávání';
$l["defaultAddressFormat"]='Výchozí formát adresy';
$l["defaultSalutation"]='Výchozí pozdrav';
$l["explanationVariables"]='Nápověda k zakládním proměnným pozdravů';
$l["explanationSex"]='Mužská a ženská podoba pozdravu';
$l["searchQueryName"]='Vyhledat název dotazu';
$l["enterSearchQueryName"]='Vložte název vyhledávacího dotazu:';
$l["photo"]= 'Fotografie';
$l["deleteImage"]='Smazat obrázek';
$l["addAllSearchResults"]='Přidat všechny výsledky vyhledávání';
$l["confirmAddAllSearchResults"]='Jste si jisti, že chcete přidat všechny výsledky hledání do seznamu adres?';
$l["moveEmployees"]='Přesunout zaměstnance';
$l["emailAdded"]='E-mailová adresa byla v pořádku přidána ke kontaktu';
$l["exportWithCompanies"]='Včetně společností';
$l["id"]='ID';
$l["exportPermission"]='Oprávnění exportu';
$l["crn"]='Společnost Reg. číslo';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Neznámá e-mailová adresa';
$l["strUnknownEmail"]= 'Tato e-mailová adresa je neznámá. Opravdu ji chcete přidat k novému kontaktu, přiřadit ke stávajícímu nebo zrušit?';
